"""
24. Составить программу для нахождения числа, которое образуется из данного натурального числа при записи его цифр в обратном порядке. Например, для числа 1234 получаем результат 4321. Использовать рекурсию. (20 баллов)
"""

def reverse_number(n):
    if n < 10:
        return n
    else:
        return (n % 10) * 10**(len(str(n)) - 1) + reverse_number(n // 10)

# Ввод числа с клавиатуры
num = int(input("Введите натуральное число: "))

# Вызов функции reverse_number и вывод результата
result = reverse_number(num)
print(f"Число, образованное из данного числа в обратном порядке: {result}")