"""
Создать класс Деньги для работы с денежными суммами. Число должно быть представлено списком, состоящим из рублей и копеек. Реализовать сложение, вычитание, деление сумм, деление денежных сумм. (20 баллов)
"""
class Деньги:
    def __init__(self, рубли, копейки):
        self.рубли = рубли
        self.копейки = копейки

    def __str__(self):
        return f"{self.рубли} руб. {self.копейки} коп."

    def __add__(self, other):
        рубли = self.рубли + other.рубли
        копейки = self.копейки + other.копейки
        if копейки >= 100:
            рубли += 1
            копейки -= 100
        return Деньги(рубли, копейки)

    def __sub__(self, other):
        рубли = self.рубли - other.рубли
        копейки = self.копейки - other.копейки
        if копейки < 0:
            рубли -= 1
            копейки += 100
        return Деньги(рубли, копейки)

    def __truediv__(self, num):
        total_kopecks = self.рубли * 100 + self.копейки
        result_kopecks = total_kopecks / num
        рубли = result_kopecks // 100
        копейки = result_kopecks % 100
        return Деньги(int(рубли), int(копейки))

    def __floordiv__(self, other):
        total1 = self.рубли * 100 + self.копейки
        total2 = other.рубли * 100 + other.копейки
        result = total1 // total2
        return result

# Пример использования класса Деньги
сумма1 = Деньги(10, 50)
сумма2 = Деньги(5, 30)

print(сумма1 + сумма2)  # Сложение денежных сумм
print(сумма1 - сумма2)  # Вычитание денежных сумм
print(сумма1 / 3)       # Деление суммы на число
print(сумма1 // сумма2)  # Деление одной суммы на другую
