"""
Дан кольцевой список с перечнем товаров. Выбрать все товары, изготовленные фирмой Bosh и создать из них новый список. (20 баллов)
"""

# Исходный кольцевой список с перечнем товаров
products = ["Товар A (Bosh)", "Товар B (Noname)", "Товар C (Bosh)", "Товар D (Samsung)", "Товар E (Bosh)"]

# Создаем новый список для товаров от фирмы Bosh
bosh_products = []

# Проходим по кольцевому списку и выбираем товары от фирмы Bosh
for product in products:
    if "Bosh" in product:
        bosh_products.append(product)

# Выводим новый список товаров от фирмы Bosh
print(bosh_products)