from setuptools import setup

setup(name='osy',
      version='0.0.2',
      author='__token__',
      description='description',
      packages=['osy'],
      author_email='skip@mail.ru',
      zip_safe=False)
